%global maintainer              cpuhouse
%global _hardened_build         1

%global libname                 libmodsecurity
%global libsoname               %{expand:%(echo %{libname} | sed 's/^lib//g')}

Name:    %{libname}
Version: 3.0.4
Release: 2%{?dist}~%{maintainer}
Summary: A library that loads/interprets rules written in the ModSecurity SecRules
License: ASL 2.0
URL:     https://www.modsecurity.org/

Source0: https://github.com/SpiderLabs/ModSecurity/releases/download/v%{version}/modsecurity-v%{version}.tar.gz

BuildRequires: gcc-c++
BuildRequires: make
BuildRequires: flex
BuildRequires: bison
BuildRequires: git-core
BuildRequires: ssdeep-devel
BuildRequires: pkgconfig(libxml-2.0)
BuildRequires: pkgconfig(yajl)
BuildRequires: pkgconfig(libcurl)
BuildRequires: pkgconfig(geoip)
BuildRequires: pkgconfig(libpcre)
BuildRequires: pkgconfig(lmdb)

# libinjection is supposed to be bundled (same as with mod_security 2.x)
# See: https://github.com/client9/libinjection#embedding
Provides: bundled(libinjection) = 3.9.2

%description
Libmodsecurity is one component of the ModSecurity v3 project.
The library codebase serves as an interface to ModSecurity Connectors
taking in web traffic and applying traditional ModSecurity processing.
In general, it provides the capability to load/interpret rules written
in the ModSecurity SecRules format and apply them to HTTP content provided
by your application via Connectors.


%package devel
Summary: Development files for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package static
Summary: Development files for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}

%description static
The %{name}-static package contains static libraries for developing
applications that use %{name}.


%prep
%autosetup -n %{libsoname}-v%{version} -S git


%build
%set_build_flags
%configure \
  --libdir=%{_libdir} \
  --with-lmdb

%make_build


%check
make test


%install
%make_install


%ldconfig_scriptlets


%files
%doc AUTHORS README.md
%{_libdir}/%{libname}.so.*
%{_bindir}/modsec-rules-check
%license LICENSE

%files devel
%doc AUTHORS README.md
%dir %{_includedir}/%{libsoname}
%{_includedir}/%{libsoname}/anchored_set_variable.h
%{_includedir}/%{libsoname}/anchored_variable.h
%{_includedir}/%{libsoname}/audit_log.h
%{_includedir}/%{libsoname}/debug_log.h
%{_includedir}/%{libsoname}/intervention.h
%{_includedir}/%{libsoname}/modsecurity.h
%{_includedir}/%{libsoname}/reading_logs_via_rule_message.h
%{_includedir}/%{libsoname}/rule.h
%{_includedir}/%{libsoname}/rule_message.h
%{_includedir}/%{libsoname}/rules.h
%{_includedir}/%{libsoname}/rules_exceptions.h
%{_includedir}/%{libsoname}/rules_properties.h
%{_includedir}/%{libsoname}/transaction.h
%{_includedir}/%{libsoname}/variable_origin.h
%{_includedir}/%{libsoname}/variable_value.h
%{_includedir}/%{libsoname}/actions/action.h
%{_includedir}/%{libsoname}/collection/collection.h
%{_includedir}/%{libsoname}/collection/collections.h
%{_libdir}/%{libname}.so
%{_libdir}/pkgconfig/%{libsoname}.pc
%license LICENSE

%files static
%{_libdir}/%{libname}.a
%{_libdir}/%{libname}.la


%changelog
* Thu Jul 02 2020 Cpuhouse DevTeam <devel@cpuhouse.com.br> - 3.0.4-2
- Enabled hardened build

* Fri Jun 05 2020 Cpuhouse DevTeam <devel@cpuhouse.com.br> - 3.0.4-1
- Spec file forked from Fedora (Othman Madjoudj <athmane@fedoraproject.org>)

# vim:number:sw=4:sts=4:ts=4:et:autoindent:syntax=spec
